Struct rustify::endpoint::MutatedEndpoint[][src]

pub struct MutatedEndpoint<'a, E: Endpoint, M: MiddleWare> { /* fields omitted */ }
Represents an Endpoint that has had MiddleWare applied to it.

This type wraps Endpoint by implementng it. The primary difference is when exec is called the request and response will potentially be mutated before processing. Only one MiddleWare can be applied to a single Endpoint.

Implementations

Returns a new MutatedEndpoint.